================================================
Telemeta : le CMS audio social, libre et ouvert
================================================

`Telemeta <http://telemeta.org>`_ est une solution libre d'archivage et d'indexation audio basée sur une interface de type web. Elle offre des fonctions avancées d'édition, d'indexation, de transcodage, de publication et de sauvegarde d'archives audio et de leurs méta-données. Il donne accès aux ressources distantes publiées ou privatisés issues de collections numérisées (fichiers, CD audio, vinyl ou bandes magnétiques) par l'intermédiaire d'un simple navigateur ou d'une application dédiée en accord avec les standards du web.

Liste des fonctionnalités principales:

 * Edition, archivage pérenne sécurisé, indexation collaborative sur la base d'une application web
 * Interface utilisateur conforme aux standards ouverts du web
 * Moteur de recherche par mots clés ou par critères (géographiques, ethniques, etc...)
 * Lecteur audio avancé dynamique et paramétrable (tous formats audio et video supportés)
 * Moteur d'analyse et de visualisation audio basée sur une structure de modules paramétrables
 * Transcodage vers les formats FLAC, OGG, MP3 et WAV avec encapsulation des métadonnées à la volée
 * Gestion complète des droits et profils utilisateurs
 * Gestion de listes de lecture personnelles avec export CSV
 * Indexation temporelle à la volée (marqueurs textuels sur le lecteur web audio)
 * Base de données relationnelle (type MySQL)
 * Service d'accès aux données par le protocole OAI-PMH (moissonnage)
 * Compatibilité `DublinCore <http://dublincore.org/>`_
 * Service de moissonnage `OAI-PMH <http://www.openarchives.org/pmh/>`_ 
 * Geo-navigateur pour la géolocalisation audio (Google Maps)
 * Flux RSS dynamique des dernières modifications
 * Sauvegarde sérialisée des archives et de leurs métadonnées aux formats WAV + XML
 * Traduction complète anglais / français (détection automatique et/ou contrainte manuelle)
 
Ce CMS audio est exclusivement basé sur des modules open source et peut être installé sur tout système Linux ou Unix.
Il est majoritairement écrit en Python et JavaScript.

|
